// SceneObject.h-  This is the base object of all objects in 
// the scene graph.
//////////////////////////////////////////////////////////////////////

#if !defined SCENEOBJECT_H
#define SCENEOBJECT_H

#include<vector>  // Use the STL Vector as our container

enum RTTI_OBJECT_TYPE
{
	RTTI_MODEL,   
	RTTI_LIGHT,    
	RTTI_DUMMY,
	RTTI_PRIMITIVE,
	RTTI_TRANSFORM,
	RTTI_MATERIAL
};

class SceneObject  
{

protected:
	SceneObject*					parentObject;
	std::vector<SceneObject*>		childrenObjects;
	
public:
	SceneObject();
	virtual ~SceneObject();

	// assessors/mutators
	void setParent(SceneObject* parent)	 { parentObject = parent; }
	void addChild(SceneObject* child);
	std::vector<SceneObject*>* getChildrenObjects() { return &childrenObjects; } 
	virtual RTTI_OBJECT_TYPE getType() const = 0;
    
	// Force every child to have a render and update methods
	virtual void render(float timeElapsed) = 0;
	virtual void update(float timeElapsed) = 0;
	
    // Optional method to override
    virtual void postRender(float timeElapsed) {}
};

#endif // SCENEOBJECT_H
